<?php
/**
 * The Configurator class.
 *
 * This class is responsible to manage theme options panel.
 *
 * @package WordPress
 */

use MailPoet\Form\FormsRepository as FormsRepository;
use MailPoet\DI\ContainerWrapper;

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'surround') );
}

if ( interface_exists('ConfigurableInterface') ) {

	class Suround_Configurator implements ConfigurableInterface
	{
		/**
		 * Contains an instance of the ReduxFramework class.
		 *
		 * @access protected
		 * @var ReduxFramework
		 */
		public $ReduxFramework;

		public $version;

		/**
		 * Contains information about the theme.
		 *
		 * @access protected
		 * @var object
		 */
		protected $theme;

		/**
		 * Contains all sections of the theme options panel.
		 *
		 * @access protected
		 * @var array
		 */
		protected $sections = array();

		/**
		 * Contains all parameters for the ReduxFramework instance.
		 *
		 * @access protected
		 * @var array
		 */
		protected $args = array();


		/**
		 * Contains options that have been setted programmatically.
		 *
		 * @access protected
		 * @var array
		 */
		protected $setted_settings = array();

		/**
		 * Constructor of the class.
		 */
		public function __construct()
		{
			if( !class_exists( 'ReduxFramework' ) ) return;

			$this->theme = wp_get_theme();

			$this->setArgs();
			$this->setSections();

			if( !isset($this->args['opt_name']) ) return;

			$this->ReduxFramework = new ReduxFramework($this->sections, $this->args);
		}

		/**
		 * Sets an option value programmatically.
		 *
		 * @param string $name - the option name
		 * @param mixed $value - value of the option
		 * @access public
		 * @return void
		 */
		public function setOption($name, $value)
		{
			$this->setted_settings[$name] = $value;
		}

		/**
		 * Returns the ReduxFramework instance.
		 *
		 * @access public
		 * @return ReduxFramework
		 */
		public function getReduxInstance()
		{
			return $this->ReduxFramework;
		}

		/**
		 * Packs all sections of the theme options panel to dedicated array.
		 *
		 * @param array $sections
		 * @access protected
		 * @return array
		 */
		public function setSections() {

			$sidebar_position = suround_sidebar_position();
			$sidebars = suround_options_sidebars();
			$header_style = suround_options_header_types();

			$mailpoet_forms = array();

			if ( defined('MAILPOET_VERSION') ) {
				$formsRepository = ContainerWrapper::getInstance()->get(FormsRepository::class);
				$forms = $formsRepository->findBy(['deletedAt' => null], ['name' => 'asc']);

				if ( $forms ) {
					foreach( $forms as $form ) {
						$mailpoet_forms[$form->getId()] = $form->getName() ? $form->getName() : 'no name';
					}
				}
			}

			$this->sections[] = array(
				'icon' => 'el-icon-dashboard',
				'icon_class' => 'icon',
				'title' => esc_html__('General', 'surround' ),
				'fields' => array(
					array(
						'id' => 'show-loading-overlay',
						'type' => 'switch',
						'title' => esc_html__( 'Loading Overlay', 'surround' ),
						'default' => false,
						'on' => esc_html__('Show', 'surround' ),
						'off' => esc_html__('Hide', 'surround' ),
					),
				)
			);


			// Logo
			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Media', 'surround' ),
				'desc'  => esc_html__( 'Personalize theme by adding your own images', 'surround' ),
				'fields' => array(
					array(
						'id' => '112',
						'type' => 'info',
						'title' => esc_html__('If header type is like 1, 2, 3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'logo',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo', 'surround' ),
						'default' => array(
							'url' => get_theme_file_uri('images/logo.png')
						)
					),
					array(
						'id' => 'logo_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo HiDPI', 'surround' ),
						'default' => array(
							'url' => get_theme_file_uri('images/logo@2x.png')
						)
					),
					array(
						'id' => '118',
						'type' => 'info',
						'title' => esc_html__('If header type is like 5, 6', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'logo_header_5',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo', 'surround' ),
						'default' => array(
							'url' => get_theme_file_uri('images/logo2.png')
						)
					),
					array(
						'id' => 'logo_header_5_hidpi',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Logo HiDPI', 'surround' ),
						'default' => array(
							'url' => get_theme_file_uri('images/logo2@2x.png')
						)
					),
					array(
						'id' => '122',
						'type' => 'info',
						'title' => esc_html__('Favicon', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'favicon',
						'type' => 'media',
						'url'=> true,
						'readonly' => false,
						'title' => esc_html__('Favicon', 'surround' ),
						'default' => array(
							'url' => get_theme_file_uri('images/favicon.png')
						)
					),
				)
			);

			// Skin Styling
			$this->sections[] = array(
				'icon' => 'el-icon-broom',
				'icon_class' => 'icon',
				'title' => esc_html__('Skin', 'surround' ),
				'fields' => array(
					array(
						'id' => 'selection-color',
						'type' => 'color',
						'desc' => esc_html__('The ::selection selector matches the portion of an element that is selected by a user.', 'surround' ),
						'title' => esc_html__('Selection background color', 'surround' ),
						'default'   => '#1e1e1e',
					),
					array(
						'id' => 'primary-color',
						'type' => 'color',
						'title' => esc_html__('Primary Color', 'surround' ),
						'default' => '#0001ff',
						'validate' => 'color',
					),
					array(
						'id' => 'map-pin-color',
						'type' => 'color',
						'title' => esc_html__('Map Pin Color', 'surround' ),
						'default' => '#0001ff',
						'validate' => 'color',
					),
					array(
						'id' => 'map-pin-text-color',
						'type' => 'color',
						'title' => esc_html__('Map Pin Text Color', 'surround' ),
						'default' => '#fafafa',
						'validate' => 'color',
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Typography', 'surround' ),
				'fields' => array(
					array(
						'id' => 'select-google-charset',
						'type' => 'switch',
						'title' => esc_html__('Select Google Font Character Sets', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'google-charsets',
						'type' => 'button_set',
						'title' => esc_html__('Google Font Character Sets', 'surround' ),
						'multi' => true,
						'required' => array('select-google-charset', 'equals', true),
						'options'=> array(
							'cyrillic' => 'Cyrrilic',
							'cyrillic-ext' => 'Cyrrilic Extended',
							'greek' => 'Greek',
							'greek-ext' => 'Greek Extended',
							'khmer' => 'Khmer',
							'latin' => 'Latin',
							'latin-ext' => 'Latin Extneded',
							'vietnamese' => 'Vietnamese'
						),
						'default' => array('latin','greek-ext','cyrillic','latin-ext','greek','cyrillic-ext','vietnamese','khmer')
					),
					array(
						'id' => 'body-font',
						'type' => 'typography',
						'title' => esc_html__('Body Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '500',
							'font-family' => 'Montserrat',
							'font-size' => '16',
							'line-height' => '28'
						),
					),
					array(
						'id' => 'h1-font',
						'type' => 'typography',
						'title' => esc_html__('H1 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '60',
							'line-height' => '70'
						),
					),
					array(
						'id' => 'h2-font',
						'type' => 'typography',
						'title' => esc_html__('H2 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '48',
							'line-height' => '56'
						),
					),
					array(
						'id' => 'h3-font',
						'type' => 'typography',
						'title' => esc_html__('H3 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '36',
							'line-height' => '42'
						),
					),
					array(
						'id'=>'h4-font',
						'type' => 'typography',
						'title' => esc_html__('H4 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '30',
							'line-height' => '35'
						),
					),
					array(
						'id' => 'h5-font',
						'type' => 'typography',
						'title' => esc_html__('H5 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '22',
							'line-height' => '28'
						),
					),
					array(
						'id' => 'h6-font',
						'type' => 'typography',
						'title' => esc_html__('H6 Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'default'=> array(
							'color' => "#1e1e1e",
							'google' => true,
							'font-weight' => '700',
							'font-family' => 'Frank Ruhl Libre',
							'font-size' => '18',
							'line-height' => '21'
						),
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Backgrounds', 'surround' ),
				'fields' => array(
					array(
						'id' => '1',
						'type' => 'info',
						'title' => esc_html__('Body Background', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'body-bg',
						'type' => 'background',
						'default'  => array(
							'background-image' => 'none',
							'background-color' => '#fff',
							'background-repeat' => 'no-repeat',
							'background-size' => 'contain',
							'background-attachment' => 'inherit',
							'background-position' => 'center top'
						),
						'title' => esc_html__('Background', 'surround' )
					)
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Main Menu', 'surround' ),
				'fields' => array(
					array(
						'id' => '12',
						'type' => 'info',
						'title' => esc_html__( 'Top Level Menu Item', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'menu-font',
						'type' => 'typography',
						'title' => esc_html__('Menu Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'line-height' => false,
						'color' => false,
						'default'=> array(
							'google' => true,
							'font-weight' => '600',
							'font-family'=> 'Montserrat',
							'font-size' => '14px',
						),
					),
					array(
						'id' => 'menu-text-transform',
						'type' => 'button_set',
						'title' => esc_html__('Text Transform', 'surround' ),
						'options' => array(
							'none' => esc_html__('None', 'surround' ),
							'capitalize' => esc_html__('Capitalize', 'surround' ),
							'uppercase' => esc_html__('Uppercase', 'surround' ),
							'lowercase' => esc_html__('Lowercase', 'surround' ),
							'initial' => esc_html__('Initial', 'surround' )
						),
						'default' => 'uppercase'
					),
					array(
						'id' => 'primary-toplevel-link-color',
						'type' => 'link_color',
						'active' => false,
						'hover' => true,
						'title' => esc_html__('Link Color', 'surround' ),
						'default' => array(
							'regular' => '#1e1e1e',
							'hover' => '#1e1e1e',
						)
					),
					array(
						'id'=>'231',
						'type' => 'info',
						'title' => esc_html__('Sub Menu', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'sub-menu-bg-color',
						'type' => 'color',
						'title' => esc_html__('Background Color for sub menu', 'surround' ),
						'default' => '#2e2e2e',
						'validate' => 'color',
					),
					array(
						'id' => 'sub-menu-multicolumn-bg-color',
						'type' => 'color',
						'title' => esc_html__('Background Color for sub menu multicolumn', 'surround' ),
						'default' => '#2e2e2e',
						'validate' => 'color',
					),
					array(
						'id' => 'sub-menu-font',
						'type' => 'typography',
						'title' => esc_html__('Sub Menu Font', 'surround' ),
						'google' => true,
						'subsets' => false,
						'font-style' => false,
						'text-align' => false,
						'line-height' => false,
						'color' => false,
						'default'=> array(
							'google' => true,
							'font-weight' => '500',
							'font-family'=> 'Montserrat',
							'font-size' => '14px'
						),
					),
					array(
						'id' => 'sub-menu-text-color',
						'type' => 'link_color',
						'title' => esc_html__('Link Color', 'surround' ),
						'default' => array(
							'regular' => '#fff',
							'hover' => '#ffd100',
							'active' => '#ffd100'
						)
					),
					array(
						'id' => '131',
						'type' => 'info',
						'title' => esc_html__('Mobile Menu', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'mobile-menu-color',
						'type' => 'color',
						'title' => esc_html__('Color for toplevel link', 'surround' ),
						'default' => '#bdbdbd',
						'validate' => 'color',
					),
					array(
						'id' => 'mobile-menu-active-color',
						'type' => 'color',
						'title' => esc_html__('Color for active toplevel link', 'surround' ),
						'default' => '#ffd100',
						'validate' => 'color',
					)
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Footer', 'surround' ),
				'fields' => array(
					array(
						'id' => 'footer-bg',
						'type' => 'background',
						'title' => esc_html__('Background', 'surround' ),
						'default' => array(
							'background-color' => '#fff',
							'background-image' => 'none',
							'background-size' => 'cover',
							'background-attachment' => 'inherit',
							'background-position' => 'center center',
							'background-repeat' => 'no-repeat'
						)
					),
					array(
						'id' => 'footer-heading-color',
						'type' => 'color',
						'title' => esc_html__('Heading Color', 'surround' ),
						'default' => '#1e1e1e',
						'validate' => 'color',
					),
				)
			);

			// Header Settings
			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Header', 'surround' ),
				'fields' => array(
					array(
						'id' => '223',
						'type' => 'info',
						'title' => esc_html__( 'Sticky Header', 'surround' ),
						'desc'    => esc_html__( 'Modify and style your sticky header area', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-sticky-menu',
						'type' => 'switch',
						'title' => esc_html__('Sticky Navigation', 'surround' ),
						'default' => true,
						'desc' => esc_html__('The sticky navigation menu is a vital part of a website, helping users move between pages and find desired information.', 'surround' ),
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id'        => 'header_sticky_offset',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Sticky header offset', 'surround' ),
						'subtitle'  => esc_html__( 'Specify after how many px of scrolling the sticky header appears', 'surround' ),
						'default'   => 600,
						'validate'  => 'numeric',
						'required' => array( 'header-sticky-menu', '=', true )
					),
					array(
						'id' => '235',
						'type' => 'info',
						'title' => esc_html__('Social Links', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'show-header-social-links',
						'type' => 'switch',
						'title' => esc_html__('Show Social Links', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => "header-social-facebook",
						'type' => 'text',
						'title' => esc_html__('Facebook', 'surround' ),
						'required' => array('show-header-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "header-social-twitter",
						'type' => 'text',
						'title' => esc_html__('Twitter', 'surround' ),
						'required' => array('show-header-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "header-social-youtube",
						'type' => 'text',
						'title' => esc_html__('Youtube', 'surround' ),
						'required' => array('show-header-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "header-social-instagram",
						'type' => 'text',
						'title' => esc_html__('Instagram', 'surround' ),
						'required' => array('show-header-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => '11',
						'type' => 'info',
						'title' => esc_html__('Search in header', 'surround' ),
						'notice' => false
					),
					array(
						'id'        => 'search_rec_posts',
						'type'      => 'select',
						'title'     => esc_html__( 'Recommended posts', 'surround' ),
						'subtitle'  => esc_html__( 'Choose a recommended posts for the search template', 'surround' ),
						'data' => 'post',
						'multi' => true,
						'default'   => ''
					),
					array(
						'id'        => 'search_per_page_limit',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts', 'surround' ),
						'subtitle'  => esc_html__( 'Specify max number of posts to display', 'surround' ),
						'default'   => 4,
					),

					array(
						'id' => '81',
						'type' => 'info',
						'title' => esc_html__('If header style is like 1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-1-cart',
						'type' => 'switch',
						'title' => esc_html__('Show cart', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-1-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-1-navbar',
						'type' => 'switch',
						'title' => esc_html__('Show Navbar', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-1-search',
						'type' => 'switch',
						'title' => esc_html__('Show search', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '34',
						'type' => 'info',
						'title' => esc_html__('If header style is like 2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-2-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-2-search',
						'type' => 'switch',
						'title' => esc_html__('Show search', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-2-navbar',
						'type' => 'switch',
						'title' => esc_html__('Show Navbar', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '31',
						'type' => 'info',
						'title' => esc_html__('If header style is like 3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-3-currently',
						'type' => 'text',
						'title' => esc_html__( 'Where are you?', 'surround' ),
						'validate' => 'html_custom',
						'default' => sprintf('<span>%s</span>', esc_html__('Australia', 'surround')),
						'allowed_html' => array(
							'p' => array(
								'class' => array()
							),
							'a' => array(
								'href' => array(),
								'title' => array()
							),
							'span' => array(),
							'br' => array(),
							'em' => array(),
							'strong' => array()
						)
					),
					array(
						'id' => 'header-style-3-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-3-search',
						'type' => 'switch',
						'title' => esc_html__('Show search', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '26',
						'type' => 'info',
						'title' => esc_html__('If header style is like 4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-4-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-4-search',
						'type' => 'switch',
						'title' => esc_html__('Show search', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-4-navbar',
						'type' => 'switch',
						'title' => esc_html__('Show Navbar', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '252',
						'type' => 'info',
						'title' => esc_html__('If header style is like 5', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-5-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-5-navbar',
						'type' => 'switch',
						'title' => esc_html__('Show Navbar', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '2345',
						'type' => 'info',
						'title' => esc_html__('If header style is like 6', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'header-style-6-show-bookmarks',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmarks', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-6-search',
						'type' => 'switch',
						'title' => esc_html__('Show search', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'header-style-6-navbar',
						'type' => 'switch',
						'title' => esc_html__('Show Navbar', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Page Header Style', 'surround' ),
				'fields' => array(
					array(
						'id' => 'header-style',
						'type' => 'image_select',
						'full_width' => true,
						'title' => esc_html__('Page Header Style', 'surround' ),
						'options' => $header_style,
						'default' => 'style-1'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Post Header Style', 'surround' ),
				'fields' => array(
					array(
						'id' => 'post-header-style',
						'type' => 'image_select',
						'full_width' => true,
						'title' => esc_html__('Post Header Style', 'surround' ),
						'options' => $header_style,
						'default' => 'style-1'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Category Header Style', 'surround' ),
				'fields' => array(
					array(
						'id' => 'category-header-style',
						'type' => 'image_select',
						'full_width' => true,
						'title' => esc_html__('Category Header Style', 'surround' ),
						'options' => $header_style,
						'default' => 'style-1'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Shop Header Style', 'surround' ),
				'fields' => array(
					array(
						'id' => 'shop-header-style',
						'type' => 'image_select',
						'full_width' => true,
						'title' => esc_html__('Shop Header Style', 'surround' ),
						'options' => $header_style,
						'default' => 'style-1'
					),
				)
			);

			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Pages', 'surround' ),
				'fields' => array(
					array(
						'id'        => 'page_content_layout',
						'type'      => 'select',
						'title'     => esc_html__( 'Content layout', 'surround' ),
						'options'   => array(
							'wide' => esc_html__( 'Wide', 'surround' ),
							'boxed' => esc_html__( 'Boxed', 'surround' ),
						),
						'default'   => 'wide'
					),
					array(
						'id' => 'page_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'right-sidebar'
					),
					array(
						'id' => 'page_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'desc' => esc_html__('Choose a page standard sidebar', 'surround'),
						'required' => array( 'page_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'general-widget-area'
					),
				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-th-large',
				'title'     => esc_html__( 'Post Layouts', 'surround' ),
				'heading' => false,
				'fields'    => array()
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_a1_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A2', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A3', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A4', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A5', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a5.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A5', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a5_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A5', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a5_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A5', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A6', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a6.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A6', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a6_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A6', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a6_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A6', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout A7', 'surround' ),
				'fields' => array(
					array(
						'id' => '11',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_a7.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout A7', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_a7_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout A7', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_a7_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout A7', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B1', 'surround' ),
				'fields' => array(
					array(
						'id' => '131',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B2', 'surround' ),
				'fields' => array(
					array(
						'id' => '131',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B3', 'surround' ),
				'fields' => array(
					array(
						'id' => '131',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B4', 'surround' ),
				'fields' => array(
					array(
						'id' => '131',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B5', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b5.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B5', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b5_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B5', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b5_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B5', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout B6', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_b6.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout B6', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_b6_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout B6', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_b6_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout B6', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);


			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout C1', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_c1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout C1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_c1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout C1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_c1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout C1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout C2', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_c2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout C2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_c2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout C2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_c2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout C2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout C3', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_c3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout C3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_c3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout C3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_c3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout C3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout C4', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_c4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout C4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_c4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout C4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_c4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout C4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout D1', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_d1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout D1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_d1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout D1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_d1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout D1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout D2', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_d2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout D2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_d2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout D2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_d2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout D2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout D3', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_d3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout D3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_d3_excerpt_limit_title',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit Title', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '35',
						'validate' => 'numeric',
					),
					array(
						'id' => 'lay_d3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout D3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_d3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout D3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout D4', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_d4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout D4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_d4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout D4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_d4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout D4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);


			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout E1', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_e1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout E1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_e1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout E1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_e1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout E1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_e1_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout E2', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_e2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout E2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_e2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout E2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_e2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout E2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_e2_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);


			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout E3', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_e3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout E3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_e3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout E3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_e3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout E3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_e3_excerpt',
						'type' => 'switch',
						'title' => esc_html__( 'Display excerpt', 'surround' ),
						'default' => true
					),
					array(
						'id' => 'lay_e3_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);


			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout E4', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_e4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout E4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_e4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout E4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_e4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout E4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					)
				)

			);



			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout F1', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_f1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout F1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_f1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout F1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_f1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout E4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					)
				)

			);



			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout F2', 'surround' ),
				'fields' => array(
					array(
						'id' => '1231',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_f2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout F2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_f2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout F2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_f2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout F2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					)
				)

			);

			$reviews_templates = array();

			if ( class_exists('RWP_Reviewer') ) {

				$templates = RWP_Reviewer::get_option('rwp_templates');

				if ( $templates ) {
					foreach( $templates as $template ) {
						$reviews_templates[$template['template_id']] = $template['template_name'];
					}
				}

			}

			$this->sections[] = array(
				'icon'      => 'el-icon-th-large',
				'title'     => esc_html__( 'Carousel Post Layouts', 'surround' ),
				'heading' => false,
				'fields'    => array(
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout G1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_g1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout G1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_g1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout G1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_g1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout G1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout G2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_g2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout G2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_g2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout G2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_g2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout G2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout G3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_g3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout G3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_g3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout G3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_g3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout G3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout G4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_g4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout G4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_g4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout G4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_g4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout G4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout H1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_h1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout H1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_h1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout H1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_h1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout H1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout H2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_h2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout H2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_h2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout H2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_h2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout H2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout H3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_h3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout H3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_h3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout H3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_h3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout H3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout H4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_h4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout H4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_h4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout H4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_h4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout H4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_i1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout I1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I1', 'surround' ),
						'default' => true
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_i2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout I2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I2', 'surround' ),
						'default' => true
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_i3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout I3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I3', 'surround' ),
						'default' => true
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I3b', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout I3b', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i3b_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I3b', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_i3b_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout I3b', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_i4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout I4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I4', 'surround' ),
						'default' => true
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout I4b', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout I4b', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_i4b_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout I4b', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_i4b_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout I4b', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout J2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout J2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_j2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout J2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_j2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout J2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout J3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout J3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_j3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout J3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_j3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout J3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout J4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout J4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_j4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout J4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_j4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout J4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout K1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_k1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout K1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_k1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout K1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_k1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout K1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_k1_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '100',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout K2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_k2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout K2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_k2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout K2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_k2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout K2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_k2_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout K3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_k3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout K3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_k3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout K3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_k3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout K3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_k3_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout K4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_k4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout K3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_k4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout K4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_k4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout K4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
					array(
						'id' => 'lay_k4_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);


			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout L1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_l1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout L1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_l1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout L1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_l1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout L1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout L2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_h2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout L2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_l2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout L2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_l2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout L2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout L3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_l3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout L3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_l3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout L3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_l3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout L3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout L4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_l4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout L4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_l4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout L4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_l4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout L4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout M1', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_m1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout M1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_m1_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout M1', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_m1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout M1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout M2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_m2.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout M1', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_m2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout M2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_m2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout M2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout M3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_m3.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout M3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_m3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout M3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_m3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout M3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout M4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_m4.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout M4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_m4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout M4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_m4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout M4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout N1', 'surround' ),
				'fields' => array(
					array(
						'id' => '3213',
						'type' => 'info',
						'title' => '<img src="'.esc_url( get_template_directory_uri().'/admin/theme-options/layouts/layout_n1.png' ).'"/>' . esc_html__('Manage options for posts displayed in Layout N1', 'surround' ),
						'notice' => false
					),
					array(
						'id'        => 'lay_n1_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout N1', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'lay_n1_excerpt_limit',
						'type' => 'text',
						'class' => 'small-text',
						'title' => esc_html__( 'Excerpt limit', 'surround' ),
						'subtitle' => esc_html__( 'Specify your excerpt limit', 'surround' ),
						'desc' => esc_html__( 'Note: Value represents number of characters', 'surround' ),
						'default' => '250',
						'validate' => 'numeric',
					)
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout N2', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout N2', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_n2_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout N2', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_n2_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout N2', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout N3', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout N3', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_n3_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout N3', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_n3_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout N3', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Layout N4', 'surround' ),
				'fields' => array(
					array(
						'id' => '321',
						'type' => 'info',
						'title' => esc_html__('Manage options for posts displayed in Layout N4', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'lay_n4_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in Layout N4', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_n4_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in Layout N4', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date' ) )
					),
				)

			);

			$this->sections[] = array(
				'icon_class' => 'el-icon-pencil',
				'title' => esc_html__('Single Post', 'surround' ),
				'fields' => array(
					array(
						'id' => 'post_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => suround_sidebar_position(true),
						'default' => 'narrow-left-sidebar'
					),
					array(
						'id' => 'post_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'post_use_sidebar','equals', suround_options_all_sidebars() ),
						'data' => 'sidebars',
						'default' => 'post-widget-area'
					),
					array(
						'id' => 'single-post-metas',
						'type' => 'button_set',
						'title' => esc_html__('Post Meta', 'surround' ),
						'multi' => true,
						'options'=> array(
							'categories' => esc_html__('Categories', 'surround' ),
							'date' => esc_html__('Date', 'surround' ),
							'comments' => esc_html__('Comments', 'surround' ),
							'-' => esc_html__('None', 'surround' )
						),
						'required' => array( 'post_user_sidebar','equals', array('no-sidebar') ),
						'desc' => esc_html__('Located at the top of the post', 'surround' ),
						'default' => array( 'categories', 'date','author', 'comments', '-' )
					),
					array(
						'id' => 'lay_single_cat',
						'type' => 'switch',
						'title' => esc_html__( 'Display category', 'surround' ),
						'subtitle' => esc_html__( 'Check if you want to display a category link for posts in single post', 'surround' ),
						'default' => true
					),
					array(
						'id'        => 'lay_single_meta',
						'type'      => 'sortable',
						'mode'      => 'checkbox',
						'title'     => esc_html__( 'Meta data', 'surround' ),
						'subtitle'  => esc_html__( 'Check which meta data to show for posts in single post', 'surround' ),
						'options'   => suround_get_meta_opts(),
						'default' => suround_get_meta_opts( array( 'date', 'views', 'vote', 'comments' ) )
					),
					array(
						'id' => 'post-tag',
						'type' => 'switch',
						'title' => esc_html__('Show Tags', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-reviewer',
						'type' => 'switch',
						'title' => esc_html__('Show Reviewer Box', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-link-bookmark',
						'type' => 'switch',
						'title' => esc_html__('Show Bookmark Link', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-author',
						'type' => 'switch',
						'title' => esc_html__('Show Author Box', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-subscribe',
						'type' => 'switch',
						'title' => esc_html__('Show Subscribe', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-subscribe-select-form',
						'type' => 'select',
						'title' => esc_html__('Select Form', 'surround' ),
						'options' => $mailpoet_forms,
						'default' => '1',
						'required' => array( 'post-subscribe', 'equals', true )
					),
					array(
						'id' => 'post-comments',
						'type' => 'switch',
						'title' => esc_html__('Show Comments', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-nav-article',
						'type' => 'switch',
						'title' => esc_html__('Navigation', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-review-template',
						'type' => 'select',
						'title' => esc_html__('Select Template for review', 'surround'),
						'options' => $reviews_templates,
						'default' => ''
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Cover Area', 'surround' ),
				'fields' => array(
					array(
						'id'        => 'post-cover-area',
						'type'      => 'select',
						'title'     => esc_html__( 'Cover area', 'surround' ),
						'subtitle'  => esc_html__( 'Choose a default cover layout for post', 'surround' ),
						'options'   => suround_get_post_cover_layouts(),
						'default'   => 'none',
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Social Share', 'surround' ),
				'fields' => array(
					array(
						'id' => 'post-social-share-buttons',
						'type' => 'button_set',
						'title' => esc_html__( 'Share buttons', 'surround' ),
						'options' => array(
							'show' => esc_html__('Show', 'surround' ),
							'hide' => esc_html__('Hide', 'surround' )
						),
						'default' => 'hide'
					),
					array(
						'id' => 'post-social-share-buttons-align',
						'type' => 'button_set',
						'title' => esc_html__('Align Share Buttons', 'surround' ),
						'options' => array(
							'position-left' => esc_html__('Left', 'surround' ),
							'position-right' => esc_html__('Right', 'surround' )
						),
						'required' => array('post-social-share-buttons','=','show'),
						'default' => 'position-left'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Related Posts', 'surround' ),
				'fields' => array(
					array(
						'id' => 'post-related-posts',
						'type' => 'switch',
						'title' => esc_html__('Show Related Posts', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'post-related-template',
						'type' => 'image_select',
						'title' => esc_html__('Select Template', 'surround'),
						'options' => array(
							'none' => array( 'title' => esc_html__( 'None', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/none.png')),
							'a3' => array( 'title' => esc_html__( 'Layout A3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_a3.png')),
							'd3' => array( 'title' => esc_html__( 'Layout D3', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d3.png')),
							'd4' => array( 'title' => esc_html__( 'Layout D4', 'surround' ), 'img' => get_theme_file_uri('admin/theme-options/layouts/layout_d4.png'))
						),
						'required' => array('post-related-posts','equals',true),
						'default' => 'a3'
					),
					array(
						'id' => 'post-related-position',
						'type' => 'button_set',
						'title' => esc_html__('Position', 'surround' ),
						'options' => array(
							'before' => esc_html__('Before comments', 'surround' ),
							'after' => esc_html__('After comments', 'surround' ),
							'bottom-fixed' => esc_html__('Bottom fixed', 'surround' )
						),
						'required' => array('post-related-posts','equals',true),
						'default' => 'after'
					),
					array(
						'id' => 'post-related-posts-count',
						'type' => 'text',
						'title' => esc_html__('Count items', 'surround' ),
						'required' => array('post-related-posts','equals',true),
						'default' => 3
					),
					array(
						'id' => 'post-related-toggle-posts-count',
						'type' => 'text',
						'title' => esc_html__('Count items for toggle related posts', 'surround' ),
						'required' => array('post-related-posts','equals',true),
						'default' => 4
					)
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Post Info', 'surround' ),
				'fields' => array(
					array(
						'id'       => 'post-info-position',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Position', 'surround' ),
						'subtitle' => esc_html__( 'Choose a position', 'surround' ),
						'options' => array(
							'left' => esc_html__('Left', 'surround' ),
							'right' => esc_html__('Right', 'surround' )
						),
						'default'  => 'left'
					)

				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Pagination', 'surround' ),
				'fields' => array(
					array(
						'id' => 'post-pag',
						'type' => 'switch',
						'title' => esc_html__('Show Pagination', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id'       => 'post-pag-type',
						'type'     => 'button_set',
						'title'    => esc_html__( 'Pagination', 'surround' ),
						'subtitle' => esc_html__( 'Choose a pagination type', 'surround' ),
						'options'  => suround_get_pagination_layouts(),
						'required' => array('post-pag','equals',true),
						'default'  => 'scroll-down'
					)

				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-folder',
				'title'     => esc_html__( 'Category Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for the category templates.', 'surround' ),
				'fields'    => array(
					array(
						'id' => 'category_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => suround_sidebar_position(true),
						'default' => 'right-sidebar'
					),
					array(
						'id' => 'category_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'category_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'category-widget-area'
					),
					array(
						'id'        => 'category_layout',
						'type'      => 'select',
						'title'     => esc_html__( 'Main layout', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how to display your posts on the category template', 'surround' ),
						'options'   => suround_get_category_layouts(),
						'default'   => 'classic',
					),
					array(
						'id' => 'category_grid_fullwidth',
						'type' => 'switch',
						'title' => esc_html__('Full Width', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
						'required'  => array( 'category_layout', '=', 'grid' ),
					),
					array(
						'id' => 'category_grid_columns',
						'type' => 'button_set',
						'title' => esc_html__('Columns for grid layout', 'surround' ),
						'options' => array(
							2 => 2,
							3 => 3,
							4 => 4,
						),
						'required'  => array( 'category_layout', '=', 'grid' ),
						'default' => 2
					),
					array(
						'id'        => 'category_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'category_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'category_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
					array(
						'id' => 'category_breadcrumb',
						'type' => 'switch',
						'title' => esc_html__('Show Breadcrumbs', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'category_position_breadcrumb',
						'type' => 'button_set',
						'title' => esc_html__('Position Breadcrumbs', 'surround' ),
						'options'=> array(
							'after' => esc_html__('After header', 'surround' ),
							'before' => esc_html__('Before content', 'surround' ),
						),
						'required'  => array( 'category_breadcrumb', '=', true ),
						'default' => 'after'
					),
					array(
						'id' => 'category_breadcrumb_align',
						'type' => 'button_set',
						'title' => esc_html__('Align Breadcrumbs', 'surround' ),
						'options'=> array(
							'center' => esc_html__('Center', 'surround' ),
							'right' => esc_html__('Right (with overlay)', 'surround' ),
						),
						'required'  => array( 'category_breadcrumb', '=', true ),
						'default' => 'center'
					),
					array(
						'id' => 'category_map',
						'type' => 'button_set',
						'title' => esc_html__('Map', 'surround' ),
						'options'=> array(
							'show' => esc_html__('Show', 'surround' ),
							'hide' => esc_html__('Hide', 'surround' ),
							'no' => esc_html__('No', 'surround' ),
						),
						'default' => 'no'
					),
					array(
						'id' => 'category_filter',
						'type' => 'switch',
						'title' => esc_html__('Show Filter', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id'        => 'category_order',
						'type'      => 'radio',
						'title'     => esc_html__( 'Order', 'surround' ),
						'options'   => array(
							'date' =>  esc_html__( 'Latest posts', 'surround' ),
							'comment_count' =>  esc_html__( 'Most commented posts', 'surround' ),
							'views' =>  esc_html__( 'Most viewed posts', 'surround' ),
						),
						'default'   => 'date',
						'required'  => array( 'category_layout', '!=', 'none' ),
					),

				)
			);

			$this->sections[] = array(
				'icon'      => ' el-icon-tag',
				'title'     => esc_html__( 'Tag Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for the tag templates', 'surround' ),
				'fields'    => array(
					array(
						'id' => 'tag_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'right-sidebar'
					),
					array(
						'id' => 'tag_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'tag_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'archive-widget-area'
					),
					array(
						'id'        => 'tag_layout',
						'type'      => 'image_select',
						'title'     => esc_html__( 'Main layout', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how to display your posts on the tag template', 'surround' ),
						'options'   => suround_get_archive_layouts(),
						'default'   => 'classic',
					),
					array(
						'id'        => 'tag_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'tag_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'tag_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-user',
				'title'     => esc_html__( 'Author Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for the author templates', 'surround' ),
				'fields' => array(
					array(
						'id'        => 'author_desc',
						'type'      => 'switch',
						'title'     => esc_html__( 'Author description', 'surround' ),
						'subtitle'  => esc_html__( 'Choose if you want to display the author avatar with bio/description', 'surround' ),
						'default'   => true
					),
					array(
						'id'        => 'author_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'author_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'author_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-search',
				'title'     => esc_html__( 'Search Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for the search results template', 'surround' ),
				'fields'    => array(

					array(
						'id' => 'search_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'right-sidebar'
					),
					array(
						'id' => 'search_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'search_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'search-widget-area'
					),
					array(
						'id'        => 'search_layout',
						'type'      => 'image_select',
						'title'     => esc_html__( 'Main layout', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how to display your posts on the search template', 'surround' ),
						'options'   => suround_get_archive_layouts(),
						'default'   => 'classic',
					),
					array(
						'id'        => 'search_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'search_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'search_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-folder-open',
				'title'     => esc_html__( 'Archive Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for other miscellaneous templates like date archives, post format archives, index (latest posts) page, etc...', 'surround' ),
				'fields'    => array(

					array(
						'id' => 'archive_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'right-sidebar'
					),
					array(
						'id' => 'archive_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'archive_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'archive-widget-area'
					),
					array(
						'id'        => 'archive_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'archive_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'archive_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
				)
			);

			$this->sections[] = array(
				'icon'      => 'el-icon-indent-left',
				'title'     => esc_html__( 'Series Template', 'surround' ),
				'desc'     => esc_html__( 'Manage settings for the series templates.', 'surround' ),
				'fields'    => array(

					array(
						'id' => 'series_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Display Sidebar', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'left-sidebar'
					),
					array(
						'id' => 'series_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'series_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'archive-widget-area'
					),
					array(
						'id'        => 'series_ppp',
						'type'      => 'radio',
						'title'     => esc_html__( 'Posts per page', 'surround' ),
						'subtitle'  => esc_html__( 'Choose how many posts per page you want to display', 'surround' ),
						'options'   => array(
							'inherit' => wp_kses( sprintf( __( 'Inherit from global option in <a href="%s">Settings->Reading</a>', 'surround' ), admin_url( 'options-reading.php' ) ), wp_kses_allowed_html( 'post' ) ),
							'custom' => esc_html__( 'Custom number', 'surround' )
						),
						'default'   => 'inherit'
					),
					array(
						'id'        => 'series_ppp_num',
						'type'      => 'text',
						'class'     => 'small-text',
						'title'     => esc_html__( 'Number of posts per page', 'surround' ),
						'default'   => get_option( 'posts_per_page' ),
						'required'  => array( 'series_ppp', '=', 'custom' ),
						'validate'  => 'numeric'
					),
				)
			);

			// Shop
			$this->sections[] = array(
				'icon' => 'el-icon-shopping-cart',
				'icon_class' => 'icon',
				'title' => esc_html__('Shop', 'surround' ),
				'fields' => array(
					array(
						'id' => 'product-archive-columns',
						'type' => 'button_set',
						'title' => esc_html__('Archive Columns', 'surround' ),
						'options' => array(
							3 => 3,
							4 => 4,
							5 => 5,
						),
						'default' => 3
					),
					array(
						'id' => 'product-archive-per-page',
						'type' => 'text',
						'title' => esc_html__('Number of products displayed per page', 'surround' ),
						'default' => 9
					),
					array(
						'id' => 'product_archive_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Page Archive Layout', 'surround' ),
						'options' => suround_sidebar_position(true),
						'default' => 'narrow-right-sidebar'
					),
					array(
						'id' => 'product_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Page Layout for base page of your shop', 'surround' ),
						'options' => suround_sidebar_position(true),
						'default' => 'narrow-right-sidebar'
					),
					array(
						'id' => 'product_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'product_use_sidebar','equals', suround_options_all_sidebars() ),
						'data' => 'sidebars',
						'default' => 'shop-widget-area'
					),
					array(
						'id' => 'product-pagetitle',
						'type' => 'switch',
						'title' => esc_html__('Show Page Title', 'surround' ),
						'default' => true,
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-sale',
						'type' => 'switch',
						'title' => esc_html__('Show "Sale" Status', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-new',
						'type' => 'switch',
						'title' => esc_html__('Show "New" Status', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),

				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Single Product', 'surround' ),
				'fields' => array(
					array(
						'id' => 'product_single_use_sidebar',
						'type' => 'image_select',
						'title' => esc_html__('Single Layout', 'surround' ),
						'options' => $sidebar_position,
						'default' => 'no-sidebar'
					),
					array(
						'id' => 'product_single_sidebar',
						'type' => 'select',
						'title' => esc_html__('Select Sidebar', 'surround' ),
						'required' => array( 'product_single_use_sidebar','equals', $sidebars ),
						'data' => 'sidebars',
						'default' => 'shop-widget-area'
					),
					array(
						'id' => 'product-upsells',
						'type' => 'switch',
						'title' => esc_html__('Show Up-Sells', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-upsells-count',
						'type' => 'text',
						'required' => array('product-upsells','equals',true),
						'title' => esc_html__('Up-Sells Count items', 'surround' ),
						'default' => 4
					),
					array(
						'id' => 'product-upsells-cols',
						'type' => 'button_set',
						'required' => array( 'product-upsells','equals',true ),
						'title' => esc_html__('Up-Sells Product Columns', 'surround' ),
						'options' => suround_product_columns(),
						'default' => 4,
					),
					array(
						'id' => '31',
						'type' => 'info',
						'title' => esc_html__('Social Links', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'product-single-share',
						'type' => 'switch',
						'title' => esc_html__('Show Social Links', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-share-facebook',
						'type' => 'switch',
						'title' => esc_html__('Enable Facebook Share', 'surround' ),
						'required' => array('product-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-share-twitter',
						'type' => 'switch',
						'title' => esc_html__('Enable Twitter Share', 'surround' ),
						'required' => array('product-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-share-pinterest',
						'type' => 'switch',
						'title' => esc_html__('Enable Pinterest Share', 'surround' ),
						'required' => array('product-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-share-email',
						'type' => 'switch',
						'title' => esc_html__('Enable Email Share', 'surround' ),
						'required' => array('product-single-share','equals',true),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Cart', 'surround' ),
				'fields' => array(
					array(
						'id' => 'product-crosssell',
						'type' => 'switch',
						'title' => esc_html__('Show Cross-Sells', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-crosssell-columns',
						'type' => 'text',
						'required' => array( 'product-crosssell','equals',true ),
						'title' => esc_html__('Cross Sells Columns', 'surround' ),
						'default' => '2'
					),
					array(
						'id' => 'product-crosssell-count',
						'type' => 'text',
						'required' => array( 'product-crosssell','equals',true ),
						'title' => esc_html__('Cross Sells Limit', 'surround' ),
						'default' => '2'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Footer', 'surround' ),
				'fields' => array(
					array(
						'id' => 'product-footer-visible',
						'type' => 'switch',
						'title' => esc_html__('Footer Visible', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'product-footer-layout',
						'type' => 'button_set',
						'title' => esc_html__('Layout', 'surround' ),
						'options' => array(
							'style-1' => esc_html__('Layout 1', 'surround' ),
							'style-2' => esc_html__('Layout 2', 'surround' ),
							'style-3' => esc_html__('Layout 3', 'surround' ),
							'style-4' => esc_html__('Layout 4', 'surround' ),
							'style-5' => esc_html__('Layout 5', 'surround' ),
						),
						'required' => array('product-footer-visible', 'equals', true),
						'default' => 'style-1'
					),
					array(
						'id' => 'footer-section',
						'type' => 'footer_section',
						'required' => array('product-footer-layout', 'equals', array('style-2', 'style-4', 'style-5')),
						'title' => esc_html__( 'Footer Section', 'surround' ),
						'desc' => esc_html__('For Layout 2, 4 and 5', 'surround'),
						'full_width' => true
					),
				)
			);

			// Javascript Code
			$this->sections[] = array(
				'icon_class' => 'el-icon-edit',
				'title' => esc_html__('Javascript Code', 'surround' ),
				'fields' => array(
					array(
						'id' => 'js-code-head',
						'type' => 'ace_editor',
						'title' => esc_html__('Javascript Code Before &lt;/head&gt;', 'surround' ),
						'subtitle' => esc_html__('Paste your JS code here.', 'surround' ),
						'mode' => 'javascript',
						'theme' => 'monokai',
						'default' => '',
						'options' => array(
							'minLines' => 35
						)
					)
				)
			);

			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Breadcrumb', 'surround'),
				'fields' => array(
					array(
						'id' => 'suround-breadcrumb-state',
						'type' => 'switch',
						'title' => esc_html__( 'Show breadcrumb section', 'surround' ),
						'default' => true,
						'on' => esc_html__('Show', 'surround'),
						'off' => esc_html__('Hide', 'surround'),
					),
					array(
						'id' => 'suround-breadcrumb',
						'type' => 'breadcrumb_section',
						'required' => array('suround-breadcrumb-state', 'equals', true),
						'title' => esc_html__( 'Breadcrumb Settings', 'surround' ),
						'full_width' => true
					)
				)

			);

			$this->sections[] = array(
				'icon'      => ' el-icon-list',
				'title'     => esc_html__( 'Sidebar', 'surround' ),
				'desc' => wp_kses( sprintf( __( 'You can manage sidebars content in the <a href="%s">Apperance -> Widgets</a> settings.', 'surround' ), admin_url( 'widgets.php' ) ), wp_kses_allowed_html( 'post' ) ),
				'fields'    => array(
					array(
						'id'        => 'sticky-sidebar',
						'type'      => 'select',
						'title'     => esc_html__( 'Sticky sidebar', 'surround' ),
						'subtitle'  => esc_html__( 'Choose a sticky sidebar', 'surround' ),
						'default'   => array('archive-widget-area', 'post-widget-area', 'general-widget-area', 'category-widget-area'),
						'multi' => true,
						'data' => 'sidebars'
					),


				)
			);

			// Footer Settings
			$this->sections[] = array(
				'icon' => 'el-icon-website',
				'icon_class' => 'icon',
				'title' => esc_html__('Footer', 'surround' ),
				'fields' => array(
					array(
						'id' => 'footer-visible',
						'type' => 'switch',
						'title' => esc_html__('Footer Visible', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'footer-layout',
						'type' => 'button_set',
						'title' => esc_html__('Layout', 'surround' ),
						'options' => array(
							'style-1' => esc_html__('Layout 1', 'surround' ),
							'style-2' => esc_html__('Layout 2', 'surround' ),
							'style-3' => esc_html__('Layout 3', 'surround' ),
							'style-4' => esc_html__('Layout 4', 'surround' ),
							'style-5' => esc_html__('Layout 5', 'surround' ),
						),
						'required' => array('footer-visible', 'equals', true),
						'default' => 'style-1'
					),
					array(
						'id' => 'show-footer-navigation',
						'type' => 'switch',
						'title' => esc_html__('Show Navigation Links', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => '205',
						'type' => 'info',
						'title' => esc_html__('Copyright', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'show-footer-copyright',
						'type' => 'switch',
						'title' => esc_html__('Show Copyright', 'surround' ),
						'default' => true,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'footer_copyright',
						'type' => 'editor',
						'title' => esc_html__( 'Copyright', 'surround' ),
						'subtitle' => esc_html__( 'Specify the copyright text to show at the bottom of the website', 'surround' ),
						'default' => sprintf( __('&copy; %s <a href="%s">%s</a>. All Rights Reserved.', 'surround' ), date('Y'), home_url('/'), get_bloginfo('blogname') ),
						'args' => array(
							'textarea_rows'    => 3  ,
							'default_editor' => 'html'
						),
						'required' => array( 'show-footer-copyright', '=', true )
					),
					array(
						'id' => '2335',
						'type' => 'info',
						'title' => esc_html__('Social Links', 'surround' ),
						'notice' => false
					),
					array(
						'id' => 'show-footer-social-links',
						'type' => 'switch',
						'title' => esc_html__('Show Social Links', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => "footer-social-facebook",
						'type' => 'text',
						'title' => esc_html__('Facebook', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "footer-social-twitter",
						'type' => 'text',
						'title' => esc_html__('Twitter', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "footer-social-googleplus",
						'type' => 'text',
						'title' => esc_html__('Google Plus', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "footer-social-youtube",
						'type' => 'text',
						'title' => esc_html__('Youtube', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "footer-social-instagram",
						'type' => 'text',
						'title' => esc_html__('Instagram', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
					array(
						'id' => "footer-social-pinterest",
						'type' => 'text',
						'title' => esc_html__('Pinterest', 'surround' ),
						'required' => array('show-footer-social-links', 'equals', true),
						'default' => '#'
					),
				)
			);

			$this->sections[] = array(
				'icon_class' => 'icon',
				'subsection' => true,
				'title' => esc_html__('Newsletter', 'surround' ),
				'fields' => array(
					array(
						'id' => 'show-footer-newsletter',
						'type' => 'switch',
						'title' => esc_html__('Show Newsletter', 'surround' ),
						'default' => false,
						'on' => esc_html__('Yes', 'surround' ),
						'off' => esc_html__('No', 'surround' ),
					),
					array(
						'id' => 'footer-newsletter-title',
						'type' => 'text',
						'title' => esc_html__('Title', 'surround' ),
						'desc' => '',
						'default' => esc_html__('Newsletter Sign Up', 'surround' ),
						'required' => array( 'show-footer-newsletter', 'equals', true )
					),
					array(
						'id' => 'footer-select-form',
						'type' => 'select',
						'title' => esc_html__('Select Form', 'surround' ),
						'options' => $mailpoet_forms,
						'default' => '1',
						'required' => array( 'show-footer-newsletter', 'equals', true )
					),
				)
			);

			// 404 Page
			$this->sections[] = array(
				'icon' => 'el-icon-error',
				'icon_class' => 'icon',
				'title' => esc_html__('404 Page', 'surround' ),
				'fields' => array(
					array(
						'id' => 'error-content',
						'type' => 'textarea',
						'title' => esc_html__('Error text', 'surround' ),
						'validate' => 'html_custom',
						'default' => sprintf('<h1>404</h1><h5>%1$s</h5><p>%2$s %3$s<a href="%4$s" class="link-text">%5$s</a> %6$s:</p>',
							esc_html__('We\'re sorry, but we can\'t find the page you were looking for.', 'surround' ),
							esc_html__('It\'s probably some thing we\'ve done wrong but now we know about it and we\'ll try to fix it.', 'surround' ),
							esc_html__('Go', 'surround'),
							home_url( '/' ),
							esc_html__('Home', 'surround'),
							esc_html__( 'or try to search', 'surround' )),
						'allowed_html' => array(
							'h1' => array(
								'class' => array()
							),
							'h2' => array(
								'class' => array()
							),
							'h3' => array(
								'class' => array()
							),
							'h4' => array(
								'class' => array()
							),
							'h5' => array(
								'class' => array()
							),
							'p' => array(
								'class' => array()
							),
							'a' => array(
								'href' => array(),
								'title' => array()
							),
							'br' => array(),
							'em' => array(),
							'strong' => array()
						)
					),
				)
			);

			// Mapbox
			$this->sections[] = array(
				'icon_class' => 'el',
				'title' => esc_html__('Mapbox', 'surround'),
				'fields' => array(
					array(
						'id' => 'mapbox-token',
						'type' => 'text',
						'title' => esc_html__('Mapbox Acess Token', 'surround'),
						'desc' => sprintf( __( 'To use any of Mapbox\'s tools, you\'ll need a Mapbox access token <a target="_blank" href="%s">access token</a>', 'surround' ), 'https://docs.mapbox.com/help/glossary/access-token/' ),
						'default' => 'pk.eyJ1Ijoic2hhZHlrIiwiYSI6ImNqdXB6OXJ4NTBzcDQzeWxqZzhtcDNta2MifQ.SSL4TxFQjPWTzl7421oqFw'
					),
					array(
						'id'       => 'map-skin',
						'type'     => 'select',
						'title'    => esc_html__( 'Map Skin', 'surround' ),
						'desc'     => '',
						'options'  => array(
							'skin1' => esc_html__('Vanilla', 'surround'),
							'skin2' => esc_html__('Midnight', 'surround'),
							'skin3' => esc_html__('Grayscale', 'surround'),
							'skin4' => esc_html__('Blue Water', 'surround'),
							'skin5' => esc_html__('Nature', 'surround'),
							'skin6' => esc_html__('Light', 'surround'),
							'skin7' => esc_html__('Teal', 'surround'),
							'skin8' => esc_html__('Iceberg', 'surround'),
							'skin9' => esc_html__('Violet', 'surround'),
							'custom' => esc_html__('Custom', 'surround'),
						),
						'default' => 'skin1'
					),
					array(
						'id' => 'map-style',
						'type' => 'textarea',
						'title' => esc_html__('Custom Map Styles', 'surround'),
						'desc' => sprintf( '%s <a href="https://www.mapbox.com/studio" target="_blank">%s</a>. %s', esc_html__('You can create custom map styles in your', 'surround'), esc_html__('Mapbox Studio', 'surround'), esc_html__('Paste the style URL (recommended).','surround') ),
						'std' => '',
						'required' => array('map-skin', 'equals', 'custom'),
						'validate' => 'js'
					),
				)
			);


			// Google
			$this->sections[] = array(
				'icon' => 'el-googleplus',
				'icon_class' => 'el',
				'title' => esc_html__('Google', 'surround'),
				'fields' => array(
					array(
						'id' => 'gmap-api',
						'type' => 'textarea',
						'title' => esc_html__('Google Maps API Key', 'surround'),
						'desc' => sprintf( '%s. <a target="_blank" href="%s">%s</a>', esc_html__('Enter a valid Google Maps API Key to use shortcode Google Map', 'surround'), 'https://developers.google.com/maps/documentation/javascript/get-api-key', esc_html__('Click here to learn more', 'surround')),
						'default' => ''
					),
				)
			);

		}


		/**
		 * Returns parameters for the ReduxFramework instance.
		 *
		 * @access protected
		 * @return array
		 */
		protected function setArgs() {
			$theme = $this->theme;

			$this->args = array(
				'opt_name'          => 'suround_settings',
				'display_name'      => $theme->get('Name') . ' ' . esc_html__('Theme Options', 'surround' ),
				'display_version'   => esc_html__('Theme Version: ', 'surround' ) . strtolower($theme->get('Version')),
				'menu_type'         => 'submenu',
				'allow_sub_menu'    => true,
				'menu_title'        => esc_html__('Theme Options', 'surround' ),
				'page_title'        => esc_html__('Theme Options', 'surround' ),
				'footer_credit'     => esc_html__('Theme Options', 'surround' ),

				'google_api_key' => 'AIzaSyBQft4vTUGW75YPU6c0xOMwLKhxCEJDPwg',
				'disable_google_fonts_link' => true,

				'async_typography'  => false,
				'admin_bar'         => false,
				'admin_bar_icon'       => 'dashicons-admin-generic',
				'admin_bar_priority'   => 50,
				'global_variable'   => '',
				'dev_mode'          => false,
				'customizer'        => false,
				'compiler'          => false,

				'page_priority'     => null,
				'page_parent'       => 'themes.php',
				'page_permissions'  => 'manage_options',
				'menu_icon'         => '',
				'last_tab'          => '',
				'page_icon'         => 'icon-themes',
				'page_slug'         => 'suround_settings',
				'save_defaults'     => true,
				'default_show'      => false,
				'default_mark'      => '',
				'show_import_export' => true,
				'show_options_object' => false,

				'transient_time'    => 60 * MINUTE_IN_SECONDS,
				'output'            => false,
				'output_tag'        => false,

				'database'              => '',
				'system_info'           => false,

				'hints' => array(
					'icon'          => 'icon-question-sign',
					'icon_position' => 'right',
					'icon_color'    => 'lightgray',
					'icon_size'     => 'normal',
					'tip_style'     => array(
						'color'         => 'light',
						'shadow'        => true,
						'rounded'       => false,
						'style'         => '',
					),
					'tip_position'  => array(
						'my' => 'top left',
						'at' => 'bottom right',
					),
					'tip_effect'    => array(
						'show'          => array(
							'effect'        => 'slide',
							'duration'      => '500',
							'event'         => 'mouseover',
						),
						'hide'      => array(
							'effect'    => 'slide',
							'duration'  => '500',
							'event'     => 'click mouseleave',
						),
					),
				),
				'ajax_save'                 => true,
				'use_cdn'                   => true,
			);
		}

		/**
		 * Returns an option value.
		 *
		 * @param string $name - the option name
		 * @param mixed $fallback - fallback value
		 * @param array $data - additional data for getting the option
		 * @access public
		 * @return mixed
		 */
		public function getOption($name, $fallback = '', array $data = array())
		{
			global $suround_settings;

			if(isset($this->setted_settings[$name])) {
				return $this->setted_settings[$name];
			}

			$current_object_id = !empty($data) && isset($data['object_id']) && !empty($data['object_id']) ? intval($data['object_id']) : get_queried_object_id();

			if( function_exists('rwmb_get_value') && isset($data['overriden_by']) && $current_object_id) {
				if ( isset($data['depend_on']) ) {

					if( rwmb_get_value($data['depend_on']['key'], null, $current_object_id) == $data['depend_on']['value'] ) {
						$overriden_by = rwmb_get_value($data['overriden_by'], null, $current_object_id);

						if($overriden_by === false && isset($suround_settings[$name])) {
							return $suround_settings[$name];
						}

						return (is_null($overriden_by) || (is_string($overriden_by) && !strlen($overriden_by)) || ($overriden_by === false)) ? $fallback : $overriden_by;
					} elseif( isset($suround_settings[$name]) ) {
						return $suround_settings[$name];
					} else {
						return $fallback;
					}
				} else {
					$overriden_by = rwmb_get_value($data['overriden_by'], null, $current_object_id);

					if ( $overriden_by == 'inherit' ) {
						if ( isset($suround_settings[$name]) ) {
							return $suround_settings[$name];
						}
					}

					return (is_null($overriden_by) || (is_string($overriden_by) && !strlen($overriden_by)) || ($overriden_by === false)) ? $fallback : $overriden_by;
				}
			}

			if ( isset($suround_settings[$name]) ) {
				return $suround_settings[$name];
			} elseif( function_exists('rwmb_get_value') && $current_object_id ) {
				$current_object_value = rwmb_get_value($name, null, $current_object_id);
				return (is_null($current_object_value) || (is_string($current_object_value) && !strlen($current_object_value)) || ($current_object_value === false)) ? $fallback : $current_object_value;
			}

			return $fallback;
		}
	}
}
?>
