<?php
/**
 * The Layout class.
 *
 * @package WordPress
 */

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'surround') );
}

if( !class_exists('Suround_Layout') && interface_exists('LayoutInterface') ) {
	class Suround_Layout implements LayoutInterface {
		/**
		 * Configurator instance.
		 *
		 * @access protected
		 * @var ConfigurableInterface
		 */
		protected $configurator;

		/**
		 * Contains header type of the current page.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $current_page_header_type;

		/**
		 * Contains single post related template.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $current_single_related_template;
		protected $current_single_post_cover_area;
		protected $current_single_pagination;

		protected $current_page_content_layout;

		/**
		 * Contains single post pagination of the current page.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $current_single_pag;

		/**
		 * Contains an array of current header items.
		 *
		 * @access protected
		 * @var null|array
		 */
		protected $current_header_items;

		/**
		 * Contains uri of the template directory.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $template_dir;

		/**
		 * Contains the current page type.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $page_type;

		/**
		 * Contains state of the breadcrumb section.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $breadcrumb_state;

		/**
		 * Contains the breadcrumb section settings.
		 *
		 * @access protected
		 * @var null|string
		 */
		protected $breadcrumb;

		/**
		 * Contains the footer sections.
		 *
		 * @access protected
		 * @var null|array
		 */
		protected $footer_sections;

		/**
		 * Contains the footer data.
		 *
		 * @access protected
		 * @var array
		 */
		protected $footer_data = array();

		protected $sidebar_state = 'suround-has-not-sidebar';

		protected $sidebar;

		/**
		 * Constructor of the class.
		 */
		public function __construct(ConfigurableInterface $configurator)
		{
			$this->configurator = $configurator;
			$this->template_dir = SUROUND_TEMPLATE_DIRECTORY_URI;

			add_action( 'wp', array($this, 'predefined_config'), 1 );
			add_action( 'wp_enqueue_scripts', array( $this, 'initialNecessaryInfo' ) );
			add_action( 'wp_loaded', array( $this, 'add_hooks' ) );
			add_action( 'body_class', array( $this, 'bodyClasses') );
		}


		/**
		 * Adds necessary classes to the body element.
		 *
		 * @access public
		 * @return array
		 */
		public function bodyClasses( $classes ) {

			global $post, $suround_config;

			if ( isset($suround_config['header_style']) ) {
				$classes[] = 'header-' . $suround_config['header_style'];
			}

			if ( is_front_page() ) {
				$classes[] = 'front__page';
			}

			$coming_soon = suround_get_meta_option('suround_coming_soon', 0);

			if ( 1 == $coming_soon ) {
				$classes[] = 'suround-coming-soon-page';
			}

			if ( is_page() ) {

				$layout = suround_get_meta_option( 'suround_cover_layout', 'none' );

				if ( !empty($layout) && $layout != 'none' ) {
					$classes[] = 'layout-type-page-' . $layout;
				}

			}

			if ( is_singular() ) {
				$classes[] = $this->get_current_page_content_layout();
			}

			if ( is_category() ) {

				$term = get_queried_object();

				if ( isset( $term->term_id ) ) {
					$meta = suround_get_category_meta($term->term_id);
					$layout = $meta['layout']['main'];
					$fullwidth = $meta['layout']['grid_fullwidth'];
					$filter = $meta['layout']['filter'];

					if ( $layout ) {
						$classes[] = 'cat-layout-' . $layout;
					}

					if ( $fullwidth ) {
						$classes[] = 'cat-layout-grid-fullwidth';
					}

					if ( $filter ) {
						$classes[] = 'cat-layout-filter';
					}

				}

			}

			$classes[] = $suround_config['sidebar_position'];

			return $classes;

		}

		public function predefined_config() {
			$this->check_page_layout();
			$this->check_header_classes();
			$this->check_footer_classes();
			$this->check_page_content_classes();
		}

		public function get_current_page_content_layout() {

			$page_layout = $this->current_page_content_layout;

			if ( !empty($page_layout) ) {
				return 'suround-page-layout-' . $page_layout;
			}
		}

		public function theme_loader() { ?><div id="loader" class="loader"></div><?php }

		public function add_hooks() {

			global $suround_settings;

			add_action( 'suround_header_after', array( $this, 'template_header_after' ) );
			add_action( 'suround_header_layout', array( $this, 'template_header_layout_hook') );

			if ( $suround_settings['show-loading-overlay'] ) {
				add_action( 'suround_body_append', array( $this, 'theme_loader' ) );
			}

			add_action( 'suround_body_append', array( $this, 'template_header_searchform' ) );

			add_action( 'suround_footer_prepend', array( $this, 'template_footer_prepend' ) );
			add_action( 'suround_footer_append', array( $this, 'template_footer_layout' ) );
		}

		function template_header_searchform() {

			?>

			<div class="searchform-wrap">

				<div class="container wide">

					<button class="close-search-form"></button>

					<form class="searchform" method="get" action="<?php echo esc_url( home_url( '/' ) ); ?>">
						<label class="searchform-label"><?php echo esc_html__( 'what are you looking for?', 'surround' ) ?></label>
						<input type="text" name="s" value="<?php echo get_search_query(); ?>"
							   placeholder="<?php esc_attr_e( 'Search Here', 'surround' ) ?>">
						<button type="submit" class="search-button"></button>
					</form>

				</div>

				<?php suround_recommended_output() ?>

			</div><!--/ .searchform-wrap-->

			<?php

		}

		public function template_header_after() {

			if ( is_category() ) {

				$term = get_queried_object();
				global $wp_query;

				if ( isset( $term->term_id ) ) {
					$meta   = suround_get_category_meta( $term->term_id );
					$layout = $meta['layout']['main'];

					if ( in_array($layout, array('classic', 'list', 'grid')) ) {

						if ( $meta['layout']['breadcrumb'] && $meta['layout']['position_breadcrumb'] == 'after' ) {
							get_template_part( 'template-parts/breadcrumb', 'category' );
						}

						if ( $meta['layout']['map'] != 'no' && $meta['layout']['position_breadcrumb'] == 'after' ) {
							get_template_part( 'template-parts/map' );
						}

					} elseif ( in_array( $layout, array('side-map')) ) {

						if ( $meta['layout']['filter'] ) {
							echo suround_output_sort_links( $wp_query->posts, 'grid', true );
						}

					}

				}

			} elseif ( is_singular('post') ) {

				switch( $this->getPostCoverArea() ) {
					case 'cover-map':
						get_template_part( 'template-parts/map' );
						break;
					case 'cover-street-view':

						if ( function_exists('wpgsv_shortcode') ) {
							echo '<div class="cover-featured-image-container">';
							echo suround_get_cover_street_view();
							echo '</div>';
						} else {
							echo '<h6>'. esc_html__( 'Please install required plugin - WP Google Street View Shortcode', 'surround' ) . '</h6>';
						}

						break;
						case 'cover-image':

							if ( has_post_thumbnail() ) {
								echo suround_get_cover_image_with_title();
							}

						break;
						case 'cover-carousel':

							$gallery = get_post_meta( suround_post_id(), 'suround_single_post_gallery' );
							if ( !empty($gallery) ) {
								echo suround_get_featured_gallery( $gallery, 3, 'suround-615x700-center-center' );
							}

						break;
						case 'cover-slider':

							$gallery = get_post_meta( suround_post_id(), 'suround_single_post_gallery' );
							if ( !empty($gallery) ) {
								echo suround_get_featured_gallery( $gallery, 1, 'suround-1640x780-center-center' );
							}

						break;
						case 'cover-video':

							$video_url = get_post_meta( get_the_ID(), 'suround_single_post_cover_video', true );

							if ( !empty($video_url) ) {
								echo suround_get_cover_video($video_url);
								echo suround_get_fixed_popup_video($video_url);
							}

						break;
					default:

					break;
				}

			} else {
				get_template_part( 'template-parts/breadcrumb' );
			}

			if ( is_page() ) {
				get_template_part( 'template-parts/page/page', 'cover' );
			}

		}

		public function template_header_layout_hook($type) {
			get_template_part( 'template-parts/header/header', $type );
		}

		public function template_footer_prepend() {

			global $SuroundLayout;

			if ( is_single() ) {
				if ( suround_get_option('post-pag') ) {
					if ( $SuroundLayout->getOption('current_single_pagination') == 'bottom-fixed' ) {
						get_template_part( 'template-parts/single/post', 'pag-bottom-fixed' );
					}
				}
			}

		}

		public function template_footer_layout($layout) {
			get_template_part( 'template-parts/footer/footer', $layout );
		}

		/*	Check page layout
		/* ---------------------------------------------------------------------- */

		public function check_page_layout () {
			global $suround_config;

			$sidebar_position = 'no-sidebar'; $sidebar = 'general-widget-area';

			if ( is_page() ) {
				$sidebar_position = $this->configurator->getOption('page_use_sidebar');
			}

			if ( is_archive() || is_front_page() || is_attachment() ) {
				$sidebar_position = $this->configurator->getOption('archive_use_sidebar');
				$sidebar = $this->configurator->getOption('archive_sidebar');
			}

			if ( is_category() ) {

				$term = get_queried_object();
				$meta = suround_get_category_meta($term->term_id);

				if ( $meta['sidebar']['type'] == 'inherit' ) {
					$sidebar_position = $this->configurator->getOption('category_use_sidebar');
					if ( $sidebar_position != 'no-sidebar' ) {
						$sidebar = $this->configurator->getOption('category_sidebar');
					}
				} else {
					$sidebar_position = $meta['sidebar']['use_sidebar'];
					if ( $sidebar_position != 'no-sidebar' ) {
						$sidebar = $meta['sidebar']['standard_sidebar'];
					}
				}

			}

			if ( is_404() )    { $sidebar_position = 'no-sidebar'; }

			if ( is_author() ) { $sidebar_position = 'no-sidebar'; }

			if ( is_singular( array('page') ) ) {
				$sidebar_position = $this->configurator->getOption('page_use_sidebar', 'right-sidebar', array(
					'overriden_by' => 'suround_page_sidebar_position'
				));

				$sidebar = $this->configurator->getOption('page_sidebar', 'general-widget-area', array(
					'overriden_by' => 'suround_page_sidebar'
				));
			}

			if ( is_tax('series') ) {
				$sidebar_position = $this->configurator->getOption('series_use_sidebar');
				if ( $sidebar_position != 'no-sidebar' ) {
					$sidebar = $this->configurator->getOption('series_sidebar');
				}
			}

			if ( is_single() ) {
				$sidebar_position = $this->configurator->getOption('post_use_sidebar', 'left-sidebar', array(
					'overriden_by' => 'suround_page_sidebar_position'
				));

				$sidebar = $this->configurator->getOption('post_sidebar', 'general-widget-area', array(
					'overriden_by' => 'suround_page_sidebar'
				));
			}

			if ( is_tag() ) {
				$sidebar_position = $this->configurator->getOption('tag_use_sidebar');
				$sidebar = $this->configurator->getOption('tag_sidebar');
			}

			if ( is_search() ) {
				$sidebar_position = $this->configurator->getOption('search_use_sidebar');
			}

			if ( suround_is_shop_installed() ) {

				if (  is_post_type_archive('product') ) {
					$sidebar_position = $this->configurator->getOption('product_use_sidebar');
				}

				if ( suround_is_realy_woocommerce_page(false) || suround_is_product_category() || suround_is_product_tax() ) {
					$sidebar_position = $this->configurator->getOption('product_archive_use_sidebar');
				}

				if ( is_cart() || is_checkout() ) {
					$sidebar_position = apply_filters( 'suround_product_cart_checkout_sidebar', 'no-sidebar' );
				}

				if ( suround_is_realy_woocommerce_page() ) {
					$sidebar = $this->configurator->getOption('product_sidebar');
				}

				if ( suround_is_product() ) {
					$sidebar_position = $this->configurator->getOption('product_single_use_sidebar');
					$sidebar = $this->configurator->getOption('product_single_sidebar');
				}

			}

			if ( !$sidebar_position ) {
				$sidebar_position = 'no-sidebar';
			}

			if ( !is_active_sidebar($sidebar) ) {
				$sidebar_position = 'no-sidebar';
			}

			if ( $sidebar_position ) {
				$suround_config['sidebar_position'] = $sidebar_position;
			}

			if ( $sidebar ) {
				$suround_config['sidebar'] = $sidebar;
			}

		}

		public function check_header_classes() {
			global $suround_config;

			$result = array();

			$header_style = $this->configurator->getOption('header-style', 'style-1', array(
				'overriden_by' => 'suround_header_style'
			));

			if ( suround_is_product() || suround_is_product_category() || suround_is_product_tag() || is_tax(get_object_taxonomies('product')) || is_post_type_archive('product')) {
				$header_style = $this->configurator->getOption('shop-header-style', 'style-1', array(
					'overriden_by' => 'suround_header_style'
				));

			} elseif ( is_post_type_archive('post') || is_singular('post') ) {
				$header_style = $this->configurator->getOption('post-header-style', 'style-1', array(
					'overriden_by' => 'suround_header_style'
				));
			} elseif ( is_category() ) {
				$header_style = $this->configurator->getOption('category-header-style', 'style-1');
			}

			$result['header_style'] = $header_style;
			$result = array_unique($result);

			$suround_config['header_classes'] = $result;
			$suround_config['header_style'] = $result['header_style'];
		}

		public function check_footer_classes() {
			global $suround_config;

			$post_id = suround_post_id();
			$result = $footer_attributes = array();
			$result[] = 'footer';

			$meta_footer_bg_img_layout_4 = trim( get_post_meta( $post_id, 'suround_footer_bg_image_layout_4', true ) );
			$meta_footer_bg_img_layout_5 = trim( get_post_meta( $post_id, 'suround_footer_bg_image_layout_5', true ) );

			$footer_layout = $this->configurator->getOption('footer-layout', 'style-1', array(
				'overriden_by' => 'suround_layout_footer'
			));

			$footer_visible = $this->configurator->getOption('footer-visible', true, array(
				'overriden_by' => 'suround_footer_visible'
			));

			if ( suround_is_shop_installed() ) {

				if ( suround_is_product() || suround_is_product_category() || suround_is_product_tag() || is_tax(get_object_taxonomies('product')) || is_post_type_archive('product')) {
					$footer_layout = $this->configurator->getOption('product-footer-layout');
					$footer_visible = $this->configurator->getOption( 'product-footer-visible' );
				}

			}

			if ( $footer_visible == 0 ) {
				$result[] = 'footer-hidden';
			}

			$result[] = $footer_layout;

			$suround_config['footer_layout'] = $footer_layout;

			$footer_attributes[] = 'class="'. implode( ' ', array_values($result) ) .'"';

			if ( $footer_layout == 'style-4' ) {
				if ( !empty($meta_footer_bg_img_layout_4) && absint($meta_footer_bg_img_layout_4) ) {
					$footer_attributes[] = 'style="background-image:url('. suround_get_post_attachment_image($meta_footer_bg_img_layout_4, '') .')"';
				}
			} elseif ( $footer_layout == 'style-5' ) {
				if ( !empty($meta_footer_bg_img_layout_5) && absint($meta_footer_bg_img_layout_5) ) {
					$footer_attributes[] = 'style="background-image:url('. suround_get_post_attachment_image($meta_footer_bg_img_layout_5, '') .')"';
				}
			}

			$suround_config['footer_attributes'] = $footer_attributes;
		}

		public function check_page_content_classes() {
			global $suround_config;

			$result = array();
			$result[] = 'page-content-wrap';
			$result[] = $suround_config['sidebar_position'];

			$suround_config['page_content_classes'] = $result;
		}

		public function initialNecessaryInfo()
		{
			$this->initialPageInfo();
			$this->initialSinglePostInfo();
			$this->initialBreadcrumbInfo();
			$this->initial404Page();

			$this->registerAssets();

			return $this;
		}

		protected function initial404Page()
		{
			if ( is_404() ) {
				$this->configurator->setOption('suround-breadcrumb-state', '0');
				$this->breadcrumb_state = 0;
			}

			return $this;
		}

		/**
		 * Fills information of the current page.
		 *
		 * @access protected
		 */
		protected function initialPageInfo()
		{

			if ( is_singular() ) {
				$this->current_page_content_layout = $this->configurator->getOption('page_content_layout', 'wide', array(
					'overriden_by' => 'suround_page_content_layout'
				));
			}

			return $this;

		}
		/**
		 * Fills information of the current single post.
		 *
		 * @access protected
		 */
		protected function initialSinglePostInfo()
		{

			if ( is_single() ) {

				$this->current_single_post_cover_area = $this->configurator->getOption('post-cover-area', 'cover-map', array(
					'overriden_by' => 'suround_single_post_cover_area',
					'depend_on' => array('key' => 'suround_single_post_cover_area_state', 'value' => '0')
				));

				$this->current_single_related_template = $this->configurator->getOption('post-related-template', 'a3', array(
					'overriden_by' => 'suround_single_post_related_template',
					'depend_on' => array('key' => 'suround_single_post_related_state', 'value' => '0')
				));

				$this->current_single_pagination = $this->configurator->getOption('post-pag-type', 'scroll-down', array(
					'overriden_by' => 'suround_single_post_pag_type',
					'depend_on' => array('key' => 'suround_single_post_pag', 'value' => '0')
				));

			}

			return $this;
		}

		/**
		 * Fills information of the current page breadcrumb section.
		 *
		 * @access protected
		 */
		protected function initialBreadcrumbInfo()
		{
			global $Suround;

			$defaults = array(
				'breadcrumb-path-delimiter' => '/',
				'content-alignment' => 'text-center',
				'background-color' => '#fff',
				'title-color' => '#1e1e1e',
				'page-title-bottom-offset' => 20,
				'content-color' => '#9e9e9e',
				'links-color' => '#1e1e1e',
				'background-image' => 'none',
				'background-image-url' => 'none',
				'background-image-opacity' => 1,
				'padding-top' => 56,
				'padding-right' => 56,
				'padding-bottom' => 56,
				'padding-left' => 56,
//				'border-width' => 0,
				'parallax' => 'on',
				'page-title-state' => 'on',
				'breadcrumb-path-state' => 'on'
			);

			if ( is_home() ) {
				$this->breadcrumb_state = '0';
				$this->breadcrumb = array();
				return $this;
			}

			if ( is_singular('post') ) {
				$this->breadcrumb_state = '0';
				$this->breadcrumb       = array();

				return $this;
			}

			if ( is_page() ) {

				$this->breadcrumb_state = $this->configurator->getOption('suround-breadcrumb-state', '1', array(
					'overriden_by' => 'suround-page-breadcrumb-state',
					'depend_on' => array( 'key' => 'suround-page-breadcrumb-settings-state', 'value' => '0' )
				));

			}  else {

				$this->breadcrumb_state = $this->configurator->getOption('suround-breadcrumb-state', '1' );

			}

			if ( !$Suround->functionalityEnabled() ) {
				$this->breadcrumb = $defaults;
			} else {

				if ( is_page() ) {

					$this->breadcrumb = $this->configurator->getOption( 'suround-breadcrumb', $defaults, array(
						'overriden_by' => 'suround-page-breadcrumb',
						'depend_on' => array( 'key' => 'suround-page-breadcrumb-settings-state', 'value' => '0' )
					) );

				} else {

					$this->breadcrumb = $this->configurator->getOption( 'suround-breadcrumb', $defaults );

				}

			}

			return $this;
		}

		/**
		 * Returns the breadcrumb section settings.
		 *
		 * @access public
		 * @return array|null
		 */
		public function getBreadcrumb()
		{
			return $this->breadcrumb_state == '1' ? $this->breadcrumb : null;
		}

		/**
		 * Returns type of the current page header.
		 *
		 * @access public
		 * @return string
		 */
		public function getHeaderType()
		{
			return $this->current_page_header_type;
		}

		/**
		 * Returns type of the current page header.
		 *
		 * @access public
		 * @return string
		 */
		public function getPostCoverArea()
		{
			return $this->current_single_post_cover_area;
		}

		/**
		 *
		 * @access public
		 * @return string
		 */
		public function getOption($option, $fallback = '') {
			if ( property_exists($this, $option) ) {
				if ( isset($this->$option) && !empty($this->$option)) {
					return $this->$option;
				}
			}
			return $fallback;
		}

		/**
		 * Returns an array of items that are in current page header.
		 *
		 * @access public
		 * @return string
		 */
		public function getHeaderItems() {
			return $this->current_header_items;
		}

		/**
		 * Registers assets that is needed for some layout parts.
		 *
		 * @access protected
		 */
		public function registerAssets() {
			// order is important

			return $this->registerInlineStyles()
						->registerStyles()
						->registerScripts();
		}

		/**
		 * Registers necessary styles.
		 *
		 * @access protected
		 */
		protected function registerStyles() {


			return $this;
		}

		/**
		 * Registers necessary inline stylesheets.
		 *
		 * @access protected
		 */
		protected function registerInlineStyles()
		{
			if ( $this->breadcrumb_state == '1' ) {
				$breadcrumb_styles = '';
				$breadcrumb_prepared = array();

				foreach ( $this->breadcrumb as $key => $value ) {
					$breadcrumb_prepared[sprintf('${%s}', $key)] = $value;
				}

				$breadcrumb_container_template = '.breadcrumbs-wrap {
					background-color: ${background-color};
					color: ${content-color};
					padding-top: ${padding-top}px;
					padding-right: ${padding-right}px;
					padding-bottom: ${padding-bottom}px;
					padding-left: ${padding-left}px;
				}';

				$breadcrumb_title_template = '.breadcrumbs-wrap .page-title {
					color: ${title-color};
					margin-bottom: ${page-title-bottom-offset}px;
				}';

				$breadcrumb_links_template = '.breadcrumbs-wrap a {
					color: ${links-color};
				}';

				$breadcrumb_styles .= str_replace(array_keys($breadcrumb_prepared), array_values($breadcrumb_prepared), $breadcrumb_container_template);
				$breadcrumb_styles .= str_replace(array_keys($breadcrumb_prepared), array_values($breadcrumb_prepared), $breadcrumb_title_template);
				$breadcrumb_styles .= str_replace(array_keys($breadcrumb_prepared), array_values($breadcrumb_prepared), $breadcrumb_links_template);

				wp_add_inline_style( 'suround-style', $breadcrumb_styles );
			}

			return $this;
		}

		/**
		 * Registers necessary scripts.
		 *
		 * @access protected
		 */
		protected function registerScripts() {

			return $this;
		}

		/**
		 * Checks sidebar settings of the page.
		 *
		 * @access protected
		 * @return void
		 */
		protected function checkSidebarState()
		{

		}

		/**
		 * Returns true in case the page is full width.
		 *
		 * @access public
		 * @return boolean
		 */
		public function isFullWidth()
		{
			if(is_page())
			{
				$this->checkSidebarState();
				return $this->sidebar_state == 'suround-full-width';
			}

			return false;
		}

		/**
		 * Returns sidebar state.
		 *
		 * @access public
		 * @return string
		 */
		public function getSidebarState()
		{
			$this->checkSidebarState();
			return in_array($this->sidebar_state, array('left-sidebar', 'right-sidebar')) ? 'has-sidebar' : 'has-not-sidebar';
		}

		/**
		 * Returns the current page sidebar.
		 *
		 * @access public
		 * @return string
		 */
		public function getSidebar()
		{
		}

		/**
		 * Returns true in case the page has sidebar.
		 *
		 * @access public
		 * @return bool
		 */
		public function hasSidebar()
		{
		}

		/**
		 * Returns true in case the page has footer.
		 *
		 * @access public
		 * @return bool
		 */
		public function hasFooter()
		{
			return is_array($this->footer_sections) && count($this->footer_sections);
		}

		/**
		 * Returns the footer data.
		 *
		 * @access public
		 * @return array
		 */
		public function getFooter()
		{
			return $this->footer_data;
		}


		/**
		 * Returns array of vertical padding of the content area.
		 *
		 * @access public
		 * @return array
		 */
		public function verticalContentPadding()
		{
		}

		/**
		 * Callback for mapping array of vertical paddings.
		 *
		 * @access public
		 * @return array
		 */
		protected function verticalContentPaddingCallback($property, $value)
		{
			return sprintf('%s: %spx;', $value, $property);
		}

		/**
		 * Returns main layout classes.
		 *
		 * @param string $column_name
		 * @access public
		 * @return string
		 */
		public function getMainLayoutClasses($column_name = 'main') {
		}

		/**
		 * Returns the current page type.
		 *
		 * @access public
		 * @return string|null
		 */
		public function getPageType()
		{
			return $this->page_type;
		}

	}
}
?>
