<?php
/**
 * The main application class
 *
 * This class is responsible to load all necessary assets, caching, theme activation, etc.
 *
 * @package WordPress
 */

// Prevent the direct loading of the file
if ( ! defined( 'ABSPATH' ) ) {
	die( esc_html__('You cannot access this file directly', 'surround') );
}

class Suround
{
	/**
	 * Contains an Suround_Admin object.
	 *
	 * @access protected
	 */
	public $admin;

	/**
	 * Contains an Suround_Helper object.
	 *
	 * @access protected
	 */
	public $helper;

	/**
	 *
	 * @static
	 * @access protected
	 * @var null|object
	 */
	protected static $instance;

	/**
	 * Contains uri of the template directory.
	 *
	 * @access protected
	 * @var null|string
	 */
	protected $template_dir;

	/**
	 * Contains the current page type (default, blogroll, portfolio, etc.).
	 *
	 * @access protected
	 * @var null|string
	 */
	protected $current_page_type;

	/**
	 * Contains the current page style (portfolio/gallery (slideshow, striped-carousel, full-page, masonry, etc.)).
	 *
	 * @access protected
	 * @var null|string
	 */
	protected $current_page_style;

	/**
	 * Contains an array of plugins that theme uses.
	 *
	 * @access protected
	 * @var array
	 */
	protected $bundled_plugins = array();

	/**
	 *
	 * @static
	 * @access public
	 * @return Suround
	 */
	public static function getInstance() {
		if( !isset( self::$instance ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Constructor of the class.
	 */
	public function __construct( ConfigurableInterface $admin = null, $helper = null ) {

		$this->admin = $admin;
		$this->helper = $helper;
//		$this->template_dir = SUROUND_TEMPLATE_DIRECTORY_URI;

		$this->addRequiredThemePlugins(array(
			array(
				'name'               => esc_html__('Surround Theme Functionality', 'surround'),
				'slug'               => 'surround-theme-functionality',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/suround/pluginus12/surround-theme-functionality.zip',
				'required'           => true,
				'version'            => '1.0.4',
			),
			array(
				'name'               => esc_html__('Reviewer', 'surround'),
				'slug'               => 'reviewer',
				'source'       => 'http://velikorodnov.com/wordpress/sample-data/suround/pluginus13/reviewer.zip',
				'required'           => true,
				'version'            => ''
			),
			array(
				'name'               => esc_html__('Meta Box Conditional Logic', 'surround'),
				'slug'               => 'meta-box-conditional-logic',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/suround/pluginus13/meta-box-conditional-logic.zip',
				'required'           => true,
				'version'            => '1.6.13'
			),
			array(
				'name'               => esc_html__('Interactive World Maps', 'surround'),
				'slug'               => 'interactive-world-maps',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/suround/pluginus13/interactive-world-maps.zip',
				'required'           => true,
				'version'            => '2.4.8'
			),
			array(
				'name'               => esc_html__('WPBakery Page Builder', 'surround'),
				'slug'               => 'js_composer',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/js_composer.zip',
				'required'           => true,
				'version'            => '7.3'
			),
			array(
				'name'               => esc_html__('Easy Tables (vc)', 'surround'),
				'slug'               => 'easy-tables-vc',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/easy-tables-vc.zip',
				'required'           => true,
				'version'            => ''
			),
			array(
				'name'               => esc_html__('Envato Market', 'surround'),
				'slug'               => 'envato-market',
				'source'             => 'http://velikorodnov.com/wordpress/sample-data/pluginusan/envato-market.zip',
				'required'           => true,
				'version'            => '2.0.7'
			),
		));

	}

	/**
	 * Returns an instance of the class that implements ConfigurableInterface interface.
	 *
	 * @access public
	 * @return ConfigurableInterface
	 */
	public function admin() {
		return $this->admin;
	}

	/**
	 * Returns an instance of the class that implements HelperInterface interface.
	 *
	 * @access public
	 * @return HelperInterface
	 */
	public function helper() {
		return $this->helper;
	}

	/**
	 * Returns an option value.
	 *
	 * @param string $name - the option name
	 * @param mixed $fallback - fallback value
	 * @param array $data - additional data for getting the option
	 * @access public
	 * @return mixed
	 */
	public function getThemeOption($name, $fallback = '', array $data = array())
	{
		if( !isset( $this->admin ) ) return $fallback;

		return $this->admin->getOption($name, $fallback, $data);
	}

	/**
	 * Sets an option value programmatically.
	 *
	 * @param string $name - the option name
	 * @param mixed $value - value of the option
	 * @access public
	 * @return void
	 */
	public function setThemeOption($name, $value)
	{
		if( !isset( $this->admin ) ) return null;

		return $this->admin->setOption($name, $value);
	}

	/**
	 * Returns array of required plugins.
	 *
	 * @access public
	 * @return array
	 */
	public function getRequiredThemePlugins()
	{
		return $this->bundled_plugins;
	}

	/**
	 * Registers required plugins.
	 *
	 * @param array $plugins
	 * @access public
	 */
	public function addRequiredThemePlugins($plugins)
	{
		$this->bundled_plugins = array_merge($this->bundled_plugins, $plugins);

		return $this;
	}


	/**
	 * Returns true when the theme options is enabled.
	 *
	 * @access public
	 * @return bool
	 */
	public function themeOptionsEnabled()
	{
		global $suround_settings;
		return isset($suround_settings) && is_array($suround_settings) && array_key_exists('post-archive-sidebar', $suround_settings);
	}

	/**
	 * Returns true when the theme functionality plugin is enabled.
	 *
	 * @access public
	 * @return bool
	 */
	public function functionalityEnabled()
	{
		global $SuroundFunctionality;
		return isset($SuroundFunctionality);
	}
}
?>
