<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Handles the management of Post meta fields.
 *
 * @since 1.0.0
 */
class Suround_Post_Writepanels {

	/**
	 * The single instance of the class.
	 *
	 * @var self
	 * @since  1.26.0
	 */
	private static $_instance = null;

	/**
	 * Allows for accessing single instance of class. Class should only be constructed once per call.
	 *
	 * @since  1.26.0
	 * @static
	 * @return self Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'add_post_meta', array( $this, 'maybe_add_geolocation_data' ), 10, 3 );
		add_action( 'update_post_meta', array( $this, 'update_post_meta' ), 10, 4 );

		add_action( 'enqueue_block_assets', array( $this, 'add_editor_css' ) );

		add_action( 'save_post', array( $this, 'save_post' ), 1, 2 );
//		add_action( 'suround_save_post', array( $this, 'save_data' ), 20, 2 );
	}

	public function add_editor_css() {
		wp_enqueue_style( 'suround-gutenberg-css', get_theme_file_uri('css/sample_editor.css') );
	}

	/**
	 * Returns configuration for custom fields on Job Listing posts.
	 *
	 * @return array
	 */
	public function post_fields() {
		global $post;

		$current_user = wp_get_current_user();

		$fields = array(
			'suround_single_post_location'    => array(
				'label'       => esc_html__( 'Location', 'surround' ),
				'placeholder' => esc_html__( 'e.g. "New York"', 'surround' ),
				'description' => esc_html__( 'Leave this blank if the location is not important.', 'surround' ),
				'priority'    => 1,
			),
		);

		$fields = apply_filters( 'suround_data_fields', $fields, $post->ID );

		uasort( $fields, array( $this, 'sort_by_priority' ) );

		return $fields;
	}

	protected function sort_by_priority( $a, $b ) {
		if ( ! isset( $a['priority'] ) || ! isset( $b['priority'] ) || $a['priority'] === $b['priority'] ) {
			return 0;
		}
		return ( $a['priority'] < $b['priority'] ) ? -1 : 1;
	}

	public function maybe_add_geolocation_data( $object_id, $meta_key, $meta_value ) {
		if ( 'suround_single_post_location' !== $meta_key || 'post' !== get_post_type( $object_id ) ) {
			return;
		}
		do_action( 'suround_post_location_edited', $object_id, $meta_value );
	}

	/**
	 * Triggered when updating meta on a job listing.
	 *
	 * @param int    $meta_id
	 * @param int    $object_id
	 * @param string $meta_key
	 * @param mixed  $meta_value
	 */
	public function update_post_meta( $meta_id, $object_id, $meta_key, $meta_value ) {
		if ( 'post' === get_post_type( $object_id ) ) {
			switch ( $meta_key ) {
				case 'suround_single_post_location':
					$this->maybe_update_geolocation_data( $meta_id, $object_id, $meta_key, $meta_value );
					break;
			}
		}
	}

	/**
	 * Generates location data if a post is updated.
	 *
	 * @param int    $meta_id (Unused).
	 * @param int    $object_id
	 * @param string $meta_key (Unused).
	 * @param mixed  $meta_value
	 */
	public function maybe_update_geolocation_data( $meta_id, $object_id, $meta_key, $meta_value ) {
		do_action( 'suround_post_location_edited', $object_id, $meta_value );
	}

	/**
	 * Handles `save_post` action.
	 *
	 * @param int     $post_id
	 * @param WP_Post $post
	 */
	public function save_post( $post_id, $post ) {
		if ( empty( $post_id ) || empty( $post ) || empty( $_POST ) ) {
			return;
		}
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return;
		}
		if ( is_int( wp_is_post_revision( $post ) ) ) {
			return;
		}
		if ( is_int( wp_is_post_autosave( $post ) ) ) {
			return;
		}
//		if ( empty( $_POST['suround_post_nonce'] ) || ! wp_verify_nonce( $_POST['suround_post_nonce'], 'save_meta_data' ) ) {
//			return;
//		}
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
		if ( 'post' !== $post->post_type ) {
			return;
		}

		/* Update Coordinate */
		if ( isset( $_REQUEST['geo_lat'], $_REQUEST['geo_lng'] ) ) {
			update_post_meta( $post_id, 'geolocation_lat', esc_attr( $_REQUEST[ 'geo_lat' ] ) );
			update_post_meta( $post_id, 'geolocation_long', esc_attr( $_REQUEST[ 'geo_lng' ] ) );
			if( isset( $_REQUEST['geo_map_lock_status'] ) ){
				$lock_status = 'lock' == $_REQUEST['geo_map_lock_status'] ? 'lock' : 'unlock';
				update_post_meta( $post_id, 'geolocation_map_lock_status', esc_attr( $lock_status ) );
			}
		}

		do_action( 'suround_save_post', $post_id, $post );
	}

	/**
	 * Handles the actual saving of post data fields.
	 *
	 * @param int     $post_id
	 * @param WP_Post $post (Unused).
	 */
	public function save_data( $post_id, $post ) {
		global $wpdb;

		// Save fields.
		foreach ( $this->post_fields() as $key => $field ) {

			if ( 'suround_single_post_location' === $key ) {
				$updated_result = update_post_meta( $post_id, $key, sanitize_text_field( $_POST[ $key ] ) );
				if ( ! $updated_result && apply_filters( 'suround_geolocation_enabled', true ) && ! Suround_Post_Geocode::has_location_data( $post_id ) ) {
					Suround_Post_Geocode::generate_location_data( $post_id, sanitize_text_field( $_POST[ $key ] ) );
				}
			}

		}

	}
}

Suround_Post_Writepanels::instance();
